@@ -1,11 +1,15 @@
 package Acme::CPANAuthors::Icelandic;
+BEGIN {
+  $Acme::CPANAuthors::Icelandic::AUTHORITY = 'cpan:HINRIK';
+}
+BEGIN {
+  $Acme::CPANAuthors::Icelandic::VERSION = '0.03';
+}
 
-use warnings;
 use strict;
+use warnings FATAL => 'all';
 use utf8;
 
-our $VERSION = '0.02';
-
 use Acme::CPANAuthors::Register (
     ADDI      => 'Arnar Mar Hrafnkelsson',
     AVAR      => 'Ævar Arnfjörð Bjarmason',
@@ -14,9 +18,8 @@ use Acme::CPANAuthors::Register (
 );
 
 1;
-__END__
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
